Name:		pcb
Version:	20110918
Release:	%mkrel 4
Summary:	An interactive printed circuit board editor
License:	GPLv2
Group:		Sciences/Other
URL:		http://pcb.sourceforge.net
Source0:	http://sourceforge.net/projects/pcb/files/%{name}/%{name}-%{version}.tar.gz
# L#882712 Route styles are not properly loaded after nm conversion
# Affected 0.20110918, reported on 2011-10-27
Patch0:         0001-Fix-parsing-of-route-styles-with-units.patch
# L#699307 Panning problem when mouse button is released on scrollbar (sf-2923335)
# Affected 0.20110918, patch from upstream's git repo, reported 2009-12-30
Patch1:         L-699307-mouse_scrolllbar.patch
# L#891041 PNG export broken for tilted, square pads
# Affected 0.20110918, reported on 2011-11-16 - Upstream has been patched on 2011-11-20
Patch2:         0001-png-hid-fixed-some-instances-of-an-int-being-used-in.patch
# Add Science category
Patch3:		pcb-desktop.patch
Patch4:		gerber_internationalisation.patch
BuildRequires:	intltool
BuildRequires:	flex
BuildRequires:	bison
BuildRequires:	gd-devel
BuildRequires:	tk
BuildRequires:	pkgconfig(dbus-1)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	gtkglext-devel
BuildRequires:	dbus-devel
BuildRequires:	gd-devel
BuildRequires:	imagemagick
BuildRequires:	mesagl-devel
BuildRequires:	mesaglu-devel
Requires:	m4

## Notes:
## 1. latest stable upstream upstream (pcb-20110918) not used due to
##    pending bugfixes from upstream (pcb tests fail)

%description
PCB is an interactive printed circuit board editor.
PCB includes a rats nest feature, design rule checking, and can provide
industry standard RS-274-X (Gerber), NC drill, and centroid data (X-Y data)
output for use in the board fabrication and assembly process. PCB offers
high end features such as an autorouter and trace optimizer which can
tremendously reduce layout time.

%prep
%setup -q
%patch0 -p1 -b -L882712
%patch1 -p1 -b -L699307
%patch2 -p1 -b -L891041
%patch3 -p1 -b -desktop
%patch4 -p1 -b -desktop

%{__sed} -i \
   's|examplesdir = $(pkgdatadir)/examples|examplesdir = @docdir@/examples|' \
   example/libraries/Makefile.*

%{__sed} -i \
   's|tutdir = $(pkgdatadir)/tutorial|tutdir = @docdir@/tutorial|' \
   tutorial/Makefile.*

%build
export CFLAGS=`echo %optflags | sed "s/-D_FORTIFY_SOURCE=2 // g" -`
%configure2_5x --enable-dbus \
	--enable-toporouter \
	--disable-update-mime-database \
	--disable-update-desktop-database \
	--docdir=%{_docdir}/%{name}-%{version}

%make

%install
%makeinstall_std

desktop-file-install --vendor ""               \
    --dir %{buildroot}%{_datadir}/applications \
    --delete-original                          \
    %{buildroot}%{_datadir}/applications/%{name}.desktop

#
# Additional Examples
#
set +x
dest=%{buildroot}%{_docdir}/%{name}-%{version}/examples
for d in thermal pad puller ; do
   echo -n -e "... Fixing path of $d  \t"
   mkdir -p $dest/$d
   mv $dest/../$d.* $dest/$d
   install -pm 0644 doc/$d.{pcb,pdf} $dest/$d
   sed -i "s|$d.png|examples/$d/$d.png|" $dest/../%{name}.html
   echo "done"
done
set -x

## --- pcb supports for acpcircuits
# http://www.apcircuits.com/resources/links/pcb_unix.html
unzip tools/apctools.zip
install -p -m 755 apc*.pl  %{buildroot}%{_datadir}/%{name}/tools

# Removes duplicates
%{__rm} -f %{buildroot}%{_datadir}/%{name}/tools/apctools.zip

# Old versions of PCB don't support autoroute, pcb2ncap convert
# pcb format to ncap format used for mucspcb to autoroute the circuit.
# In newer versions of PCB, autoroute is included and pcb2ncap and mucspcb
# are no more needed.
%{__rm} -f %{buildroot}%{_datadir}/%{name}/tools/pcb2ncap.tgz

chmod 755 %{buildroot}%{_datadir}/%{name}/tools/{PCB2HPGL,tgo2pcb.tcl,Merge*}

cp -p AUTHORS COPYING README NEWS ChangeLog README_FILES/CHANGES \
      README_FILES/Whats_new_in_2.0 README_FILES/Tools \
      %{buildroot}%{_docdir}/%{name}-%{version}/

%{__rm} -rf %{buildroot}%{_datadir}/info/dir

mv %{buildroot}%{_docdir}/%{name}-%{version}/refcard.pdf %{buildroot}%{_docdir}/%{name}-%{version}/pcb-reference-card.pdf

# remove duplicates
%{__rm} -f %{buildroot}%{_bindir}/Merge*

# L#854396 0.20110918 needlessly installs gts static library & header file
%{__rm} -f %{buildroot}%{_libdir}/libgts.a %{buildroot}%{_includedir}/gts.h

%find_lang %{name}

%check
%make check

%files -f %{name}.lang
%doc %{_docdir}/%{name}-%{version}/*
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}
%{_datadir}/gEDA/scheme/*
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}*
%{_infodir}/%{name}.info*
%{_iconsdir}/hicolor/*/mimetypes/application-x-*
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_datadir}/mime/packages/pcb.xml
%{_datadir}/mimelnk/application/x-*.desktop


%changelog
* Sat Oct 19 2013 umeabot <umeabot> 20110918-4.mga4
+ Revision: 523998
- Mageia 4 Mass Rebuild

* Thu Jan 24 2013 juergen_harms <juergen_harms> 20110918-3.mga4
+ Revision: 391763
- Introduce Internationalisation patch for gerber output
- Bump release

* Sun Jan 13 2013 umeabot <umeabot> 20110918-2.mga3
+ Revision: 362635
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Oct 25 2012 dams <dams> 20110918-1.mga3
+ Revision: 309966
- update/fix %%group
- new snapshot 20110918
- clean specfile
- add upstream patches to fix issues
- add a patch to fix .desktop

* Sun Mar 04 2012 wally <wally> 20100929-5.mga2
+ Revision: 217847
- clean BRs
- clean .spec a bit

* Sat Mar 03 2012 wally <wally> 20100929-4.mga2
+ Revision: 217362
- add post and preun scripts for info files

* Fri Mar 02 2012 juergen_harms <juergen_harms> 20100929-3.mga2
+ Revision: 216732
- revert to revision 210024 (pcb-20100929-1.mga-2), but
  +   bump release
  +   correct libcanberra0 dependency
- correct libcanberra dependency to %%{_lib}canberra0
- suppress building info files (drop post and preun, texinfo and texlive again)
- add BuildRequires texlive (for makeinfo)
- add BuildRequires texinfo (for makeinfo)
- add preun and post clauses (info install and remove)
- temporary fix to correct FSF addresses (prep section)

* Fri Feb 17 2012 juergen_harms <juergen_harms> 20100929-1.mga2
+ Revision: 210024
- import upstream releas 20100929
- correct source URL at sourceforge
- drop patches obsoleted by upstream development
- add missing files in %%files section:
  + MergePCBPS
  + Merge_dimPCBPS
  + gEDA/scheme/
- add dependency on libcanberra-gtk0
- imported package pcb


* Sun Jul 11 2010 Funda Wang <fwang@mandriva.org> 20091103-1mdv2011.0
+ Revision: 550614
- import pcb


